==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey.md <==
# AwsIdentityAccessManagementDataEncryptionKey


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')
```



| Illustration | AwsIdentityAccessManagementDataEncryptionKey | AwsIdentityAccessManagementDataEncryptionKeyCard | AwsIdentityAccessManagementDataEncryptionKeyGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey.png) | ![illustration for AwsIdentityAccessManagementDataEncryptionKey](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey.Local.png) | ![illustration for AwsIdentityAccessManagementDataEncryptionKeyCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKeyCard.Local.png) | ![illustration for AwsIdentityAccessManagementDataEncryptionKeyGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKeyGroup.Local.png) |




## AwsIdentityAccessManagementDataEncryptionKey

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKey
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKey('AwsIdentityAccessManagementDataEncryptionKey', 'Aws Identity Access Management Data Encryption Key', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKey
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKey('AwsIdentityAccessManagementDataEncryptionKey', 'Aws Identity Access Management Data Encryption Key', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementDataEncryptionKeyCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKeyCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKeyCard('AwsIdentityAccessManagementDataEncryptionKeyCard', 'Aws Identity Access Management Data Encryption Key Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKeyCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKeyCard('AwsIdentityAccessManagementDataEncryptionKeyCard', 'Aws Identity Access Management Data Encryption Key Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementDataEncryptionKeyGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKeyGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKeyGroup('AwsIdentityAccessManagementDataEncryptionKeyGroup', 'Aws Identity Access Management Data Encryption Key Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKeyGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKeyGroup('AwsIdentityAccessManagementDataEncryptionKeyGroup', 'Aws Identity Access Management Data Encryption Key Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey.md <==
# AwsIdentityAccessManagementDataEncryptionKey


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')
```



| Illustration | AwsIdentityAccessManagementDataEncryptionKey | AwsIdentityAccessManagementDataEncryptionKeyCard | AwsIdentityAccessManagementDataEncryptionKeyGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey.png) | ![illustration for AwsIdentityAccessManagementDataEncryptionKey](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey.Local.png) | ![illustration for AwsIdentityAccessManagementDataEncryptionKeyCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKeyCard.Local.png) | ![illustration for AwsIdentityAccessManagementDataEncryptionKeyGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKeyGroup.Local.png) |




## AwsIdentityAccessManagementDataEncryptionKey

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKey
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKey('AwsIdentityAccessManagementDataEncryptionKey', 'Aws Identity Access Management Data Encryption Key', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKey
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKey('AwsIdentityAccessManagementDataEncryptionKey', 'Aws Identity Access Management Data Encryption Key', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementDataEncryptionKeyCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKeyCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKeyCard('AwsIdentityAccessManagementDataEncryptionKeyCard', 'Aws Identity Access Management Data Encryption Key Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKeyCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKeyCard('AwsIdentityAccessManagementDataEncryptionKeyCard', 'Aws Identity Access Management Data Encryption Key Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementDataEncryptionKeyGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKeyGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKeyGroup('AwsIdentityAccessManagementDataEncryptionKeyGroup', 'Aws Identity Access Management Data Encryption Key Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementDataEncryptionKeyGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementDataEncryptionKey')

' renders the element
AwsIdentityAccessManagementDataEncryptionKeyGroup('AwsIdentityAccessManagementDataEncryptionKeyGroup', 'Aws Identity Access Management Data Encryption Key Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
